@@ -11,7 +11,7 @@ pub mod constants;
 pub mod functions;
 /// Reference implementations of patterns.
 pub mod patterns {
-    pub mod api_entry;
+    // pub mod api_entry;
     pub mod api_guard;
     pub mod ascii_pointer;
     pub mod callbacks;
@@ -74,12 +74,15 @@ interoptopus::inventory!(
         patterns::slice::pattern_ffi_slice_1,
         patterns::slice::pattern_ffi_slice_2,
         patterns::slice::pattern_ffi_slice_3,
+        patterns::slice::pattern_ffi_slice_4,
+        patterns::slice::pattern_ffi_slice_5,
+        patterns::slice::pattern_ffi_slice_6,
         patterns::slice::pattern_ffi_slice_delegate,
         patterns::slice::pattern_ffi_slice_delegate_huge,
         patterns::option::pattern_ffi_option_1,
         patterns::option::pattern_ffi_option_2,
         patterns::primitives::pattern_ffi_bool,
-        patterns::api_entry::pattern_my_api_init_v1,
+        // patterns::api_entry::pattern_my_api_init_v1,
         patterns::api_guard::pattern_api_guard,
         patterns::callbacks::pattern_callback_1,
     ],
