@@ -1,22 +1,7 @@
-use crate::patterns::result::FFIError;
+use crate::patterns::result::{Error, FFIError};
 use interoptopus::patterns::primitives::FFIBool;
 use interoptopus::patterns::slice::{FFISlice, FFISliceMut};
 use interoptopus::{ffi_service, ffi_service_ctor, ffi_service_method, ffi_type};
-use std::fmt::{Display, Formatter};
-
-// An error we use in a Rust library
-#[derive(Debug)]
-pub enum Error {
-    Bad,
-}
-
-impl Display for Error {
-    fn fmt(&self, _: &mut Formatter<'_>) -> std::fmt::Result {
-        Ok(())
-    }
-}
-
-impl std::error::Error for Error {}
 
 /// Some struct we want to expose as a class.
 #[ffi_type(opaque)]
@@ -34,6 +19,16 @@ impl SimpleService {
         Ok(Self { some_value })
     }
 
+    #[ffi_service_ctor]
+    pub fn new_without() -> Result<Self, Error> {
+        Ok(Self { some_value: 0 })
+    }
+
+    #[ffi_service_ctor]
+    pub fn new_failing(_some_value: u8) -> Result<Self, Error> {
+        Err(Error::Bad)
+    }
+
     /// Methods returning a Result<(), _> are the default and do not
     /// need annotations.
     pub fn method_result(&self, _: u32) -> Result<(), Error> {
@@ -75,17 +70,15 @@ impl SimpleService {
         *x
     }
 
-    #[ffi_service_method(direct)]
-    pub fn method_mut_self_ffi_error(&mut self, _slice: FFISliceMut<u8>) -> FFIError {
-        FFIError::Ok
+    pub fn method_mut_self_ffi_error(&mut self, _slice: FFISliceMut<u8>) -> Result<(), Error> {
+        Ok(())
     }
-}
 
-impl From<Error> for FFIError {
-    fn from(x: Error) -> Self {
-        match x {
-            Error::Bad => Self::Fail,
-        }
+    #[ffi_service_method(direct)]
+    pub fn method_mut_self_no_error(&mut self, _slice: FFISliceMut<u8>) {}
+
+    pub fn method_void_ffi_error(&mut self) -> Result<(), Error> {
+        Ok(())
     }
 }
 
